import * as THREE from "three";
import { Application } from "./core";
export declare type MeshMaterialType = THREE.MeshBasicMaterial | THREE.MeshDepthMaterial | THREE.MeshFaceMaterial | THREE.MeshLambertMaterial | THREE.MeshNormalMaterial | THREE.MeshPhongMaterial | THREE.MeshStandardMaterial | THREE.ShaderMaterial | THREE.ShadowMaterial;
export declare type GeometryType = THREE.Geometry | THREE.BufferGeometry;
export declare type MaterialType = MeshMaterialType;
export declare type TextureType = THREE.Texture;
export declare type ModelType = THREE.Object3D;
export declare type AssetType = GeometryType | MaterialType | TextureType | ModelType;
export declare type ModelFactory = (app: Application) => Promise<ModelType>;
export declare type GeometryFactory = (app: Application) => Promise<GeometryType>;
export declare type MaterialFactory = (app: Application) => Promise<MaterialType>;
export declare type TextureFactory = (app: Application) => Promise<TextureType>;
export declare type LightFactory = () => Promise<THREE.Light>;
export declare type CameraFactory = (size: {
    width: number;
    height: number;
}) => Promise<THREE.Camera>;
export interface DisposableAsset {
    dispose?: () => void;
}
export declare enum AssetTypes {
    TEXTURE = "TEXTURE",
    MATERIAL = "MATERIAL",
    GEOMETRY = "GEOMETRY",
    MODEL = "MODEL"
}
